@@ -4,6 +4,8 @@ import json
 import chardet
 from LogService import LogServiceClass
 import random,time
+import urllib3
+urllib3.disable_warnings()
 
 class HttpServiceClass(object):
     Log = LogServiceClass(tag="HttpServiceClass")
