@@ -11,11 +11,11 @@ class MailServiceClass(object):
     def __init__(self):
         self.mail_host='smtp.qq.com'  #设置服务器
         self.mail_user='1620829248@qq.com'    #用户名
-        self.mail_pass='askqrqhzcusfcddf'   #口令 
+        self.mail_pass='vsjgukkyzjjcfacd'#"lkkjyommgyuzfabh"#"askqrqhzcusfcddf"   #口令 
         self.sender = '1620829248@qq.com'
         self.receiversInit = ['877665041@qq.com']  # 接收邮件，可设置为你的QQ邮箱或者其他邮箱
     
-    def SendMail(self, userName, title, content, receivers):
+    def SendMail(self, userName, title, content, receiverMail):
         msgRoot = MIMEMultipart('related')
         msgRoot['From'] = Header(userName, 'utf-8')
         msgRoot['To'] =  Header('用户', 'utf-8')
@@ -47,7 +47,7 @@ class MailServiceClass(object):
 
         receiversTemp = []
         receiversTemp.extend(self.receiversInit)
-        receiversTemp.extend(receivers)
+        receiversTemp.extend(receiverMail)
         reTitle = title
         if len(title + content) < 256 :
         	reTitle = title + content
@@ -55,15 +55,13 @@ class MailServiceClass(object):
             smtpObj = smtplib.SMTP() 
             smtpObj.connect(self.mail_host, 25)    # 25 为 SMTP 端口号
             smtpObj.login(self.mail_user,self.mail_pass)
-            smtpObj.sendmail(self.sender, receivers, msgRoot.as_string())
+            smtpObj.sendmail(self.sender, receiverMail, msgRoot.as_string())
             print ('邮件发送成功')
-            tools.SendNotify('邮件：{}'.format(reTitle), '{}'.format(content))
-            tools.SendQQMsg('private', 1620829248, '邮件：{}'.format(reTitle)+'\n'+'{}'.format(content))
+            tools.SendNotify('邮件：%s \n %s'%(reTitle, content))
             return {True, '邮件发送成功'}
         except smtplib.SMTPException as e:
             print ('Error: 无法发送邮件' + str(e))
-            tools.SendNotify('邮件：{}'.format(reTitle), '{}  \n  {}'.format(content,str(e)))
-            tools.SendQQMsg('private', 1620829248, '邮件：{}'.format(reTitle)+'\n'+ '{}  \n  {}'.format(content,str(e)))
+            tools.SendNotify('邮件：%s \n %s \n %s'%(reTitle, content, str(e)))
             return {False, 'Error: 无法发送邮件'}
 
 if __name__ == '__main__':
