@@ -171,12 +171,12 @@ class VideoEditorServiceClass():
         return tempPath, save_path
 
     # 视频添加LOG  VideoClipAddLogoPath
-    def video_add_log(self, videoPath, save_path, logoPngPath = None, logoTextStr = None, Opacity = 1):
+    def video_add_log(self, videoPath, save_path, logoPngPath = None, logoTextStr = None, color='white', align='center', fontsize = 25, left=0, top=0, right=0, bottom=0, opacity=0, pos=('center','center'), fontPath=None):
         tempPath, save_path = self._video_path_handle(videoPath, save_path)
         if logoPngPath == None and logoTextStr == None:
             return self.result_param(False, save_path, None, None, '没有设置水印')
 
-        clipList = []
+        clipList = []        
         video = VideoFileClip(tempPath)
         clipList.append(video)
         logoPngClip = None
@@ -185,17 +185,20 @@ class VideoEditorServiceClass():
             logoPngClip = (ImageClip(logoPngPath)
                     .set_duration(video.duration)  # 水印持续时间
                     .resize(height=50)  # 水印的高度，会等比缩放
-                    .margin(right=8, top=8, opacity= Opacity)  # 水印边距和透明度
-                    .set_pos(("right","top")))  # 水印的位置
+                    .margin(left=left, top=top, right=right, bottom=bottom, opacity = opacity)# 水印边距和透明度
+                    .set_pos(pos))  # 水印的位置
             clipList.append(logoPngClip)
 
         if logoTextStr != None:
-            FONT_URL = r'C:/Windows/Fonts/simsun.ttc'  #r'C:\Windows\Fonts\simhei.ttf'    #C:\Windows\Fonts\STXINGKA.TTF'
-            logoTextClip = (TextClip(txt=logoTextStr, color='white', size=(640, 480), method='caption',
-                    align='center', fontsize=25, font=FONT_URL)
+            FONT_URL = fontPath or r'C:/Windows/Fonts/simsun.ttc'  #r'C:\Windows\Fonts\simhei.ttf'    #C:\Windows\Fonts\STXINGKA.TTF'
+            if not os.path.exists(FONT_URL):
+                print("字体文件不存在 %s"%FONT_URL)
+                return False
+            logoTextClip = (TextClip(txt=logoTextStr, color=color, size=(640, 480), method='caption',
+                    align=align, fontsize=fontsize, font=FONT_URL)
                     .set_duration(video.duration)
-                    .margin(right=8, top=8, opacity = Opacity)
-                    .set_pos(("right","top")))  # 水印的位置
+                    .margin(left=left, top=top, right=right, bottom=bottom, opacity = opacity)
+                    .set_pos(pos))  # 水印的位置
             clipList.append(logoTextClip)
 
         if len(clipList) == 0:
@@ -247,7 +250,7 @@ class VideoEditorServiceClass():
         video_target = VideoFileClip(video_path_target)
         audio = video_source.audio
         videoclip = video_target.set_audio(audio)
-        videoclip.write_videofile(out_video_path)
+        videoclip.write_videofile(out_video_path, audio_codec="aac")
         return self.result_param(True, out_video_path, videoclip, None, '')
 
     # 为视频添加的音频
@@ -255,7 +258,7 @@ class VideoEditorServiceClass():
         video = VideoFileClip(video_path)
         audio = AudioFileClip(audio_path).subclip(0, video.duration)
         videoclip = video.set_audio(audio)
-        videoclip.write_videofile(out_video_path)
+        videoclip.write_videofile(out_video_path, audio_codec="aac")
         return self.result_param(True, out_video_path, videoclip, None, '')
 
     # --------------------------------------------Tools Start------------------------------------------------
